logs

package
v0.0.18 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 28, 2026 License: Apache-2.0 Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var File_services_logs_v1_logs_proto protoreflect.FileDescriptor
var LogService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "services.logs.v1.LogService",
	HandlerType: (*LogServiceServer)(nil),
	Methods:     []grpc.MethodDesc{},
	Streams: []grpc.StreamDesc{
		{
			StreamName:    "TailLogs",
			Handler:       _LogService_TailLogs_Handler,
			ServerStreams: true,
		},
		{
			StreamName:    "PushLogs",
			Handler:       _LogService_PushLogs_Handler,
			ClientStreams: true,
		},
	},
	Metadata: "services/logs/v1/logs.proto",
}

LogService_ServiceDesc is the grpc.ServiceDesc for LogService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterLogServiceServer

func RegisterLogServiceServer(s grpc.ServiceRegistrar, srv LogServiceServer)

Types

type LogEntry

type LogEntry struct {
	NodeId    string                 `protobuf:"bytes,1,opt,name=node_id,json=nodeId,proto3" json:"node_id,omitempty"`
	TaskId    string                 `protobuf:"bytes,2,opt,name=task_id,json=taskId,proto3" json:"task_id,omitempty"`
	SessionId string                 `protobuf:"bytes,3,opt,name=session_id,json=sessionId,proto3" json:"session_id,omitempty"`
	Timestamp *timestamppb.Timestamp `protobuf:"bytes,4,opt,name=timestamp,proto3" json:"timestamp,omitempty"`
	Line      string                 `protobuf:"bytes,5,opt,name=line,proto3" json:"line,omitempty"`
	Seq       uint64                 `protobuf:"varint,6,opt,name=seq,proto3" json:"seq,omitempty"`
	// contains filtered or unexported fields
}

func (*LogEntry) Descriptor deprecated

func (*LogEntry) Descriptor() ([]byte, []int)

Deprecated: Use LogEntry.ProtoReflect.Descriptor instead.

func (*LogEntry) GetLine

func (x *LogEntry) GetLine() string

func (*LogEntry) GetNodeId

func (x *LogEntry) GetNodeId() string

func (*LogEntry) GetSeq

func (x *LogEntry) GetSeq() uint64

func (*LogEntry) GetSessionId

func (x *LogEntry) GetSessionId() string

func (*LogEntry) GetTaskId added in v0.0.11

func (x *LogEntry) GetTaskId() string

func (*LogEntry) GetTimestamp

func (x *LogEntry) GetTimestamp() *timestamppb.Timestamp

func (*LogEntry) ProtoMessage

func (*LogEntry) ProtoMessage()

func (*LogEntry) ProtoReflect

func (x *LogEntry) ProtoReflect() protoreflect.Message

func (*LogEntry) Reset

func (x *LogEntry) Reset()

func (*LogEntry) String

func (x *LogEntry) String() string

type LogServiceClient

type LogServiceClient interface {
	TailLogs(ctx context.Context, in *TailLogRequest, opts ...grpc.CallOption) (LogService_TailLogsClient, error)
	PushLogs(ctx context.Context, opts ...grpc.CallOption) (LogService_PushLogsClient, error)
}

LogServiceClient is the client API for LogService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewLogServiceClient

func NewLogServiceClient(cc grpc.ClientConnInterface) LogServiceClient

type LogServiceServer

type LogServiceServer interface {
	TailLogs(*TailLogRequest, LogService_TailLogsServer) error
	PushLogs(LogService_PushLogsServer) error
	// contains filtered or unexported methods
}

LogServiceServer is the server API for LogService service. All implementations must embed UnimplementedLogServiceServer for forward compatibility

type LogService_PushLogsClient

type LogService_PushLogsClient interface {
	Send(*LogEntry) error
	CloseAndRecv() (*emptypb.Empty, error)
	grpc.ClientStream
}

type LogService_PushLogsServer

type LogService_PushLogsServer interface {
	SendAndClose(*emptypb.Empty) error
	Recv() (*LogEntry, error)
	grpc.ServerStream
}

type LogService_TailLogsClient

type LogService_TailLogsClient interface {
	Recv() (*LogEntry, error)
	grpc.ClientStream
}

type LogService_TailLogsServer

type LogService_TailLogsServer interface {
	Send(*LogEntry) error
	grpc.ServerStream
}

type TailLogRequest

type TailLogRequest struct {
	NodeId       string `protobuf:"bytes,1,opt,name=node_id,json=nodeId,proto3" json:"node_id,omitempty"`
	TaskId       string `protobuf:"bytes,2,opt,name=task_id,json=taskId,proto3" json:"task_id,omitempty"`
	SessionId    string `protobuf:"bytes,3,opt,name=session_id,json=sessionId,proto3" json:"session_id,omitempty"`
	Watch        bool   `protobuf:"varint,4,opt,name=watch,proto3" json:"watch,omitempty"`
	SinceSeconds int64  `protobuf:"varint,5,opt,name=since_seconds,json=sinceSeconds,proto3" json:"since_seconds,omitempty"`
	Tail         int64  `protobuf:"varint,6,opt,name=tail,proto3" json:"tail,omitempty"`
	Limit        int64  `protobuf:"varint,8,opt,name=limit,proto3" json:"limit,omitempty"`
	// contains filtered or unexported fields
}

func (*TailLogRequest) Descriptor deprecated

func (*TailLogRequest) Descriptor() ([]byte, []int)

Deprecated: Use TailLogRequest.ProtoReflect.Descriptor instead.

func (*TailLogRequest) GetLimit added in v0.0.16

func (x *TailLogRequest) GetLimit() int64

func (*TailLogRequest) GetNodeId

func (x *TailLogRequest) GetNodeId() string

func (*TailLogRequest) GetSessionId

func (x *TailLogRequest) GetSessionId() string

func (*TailLogRequest) GetSinceSeconds

func (x *TailLogRequest) GetSinceSeconds() int64

func (*TailLogRequest) GetTail added in v0.0.16

func (x *TailLogRequest) GetTail() int64

func (*TailLogRequest) GetTaskId added in v0.0.11

func (x *TailLogRequest) GetTaskId() string

func (*TailLogRequest) GetWatch

func (x *TailLogRequest) GetWatch() bool

func (*TailLogRequest) ProtoMessage

func (*TailLogRequest) ProtoMessage()

func (*TailLogRequest) ProtoReflect

func (x *TailLogRequest) ProtoReflect() protoreflect.Message

func (*TailLogRequest) Reset

func (x *TailLogRequest) Reset()

func (*TailLogRequest) String

func (x *TailLogRequest) String() string

type UnimplementedLogServiceServer

type UnimplementedLogServiceServer struct {
}

UnimplementedLogServiceServer must be embedded to have forward compatible implementations.

func (UnimplementedLogServiceServer) PushLogs

func (UnimplementedLogServiceServer) TailLogs

type UnsafeLogServiceServer

type UnsafeLogServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeLogServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to LogServiceServer will result in compilation errors.

Jump to