store

package
v0.0.18 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 28, 2026 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Overview

Package store provides an interface as well as implementations for storing proto messages to various surfaces.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ProtoStore added in v0.0.18

type ProtoStore interface {
	Load(string, proto.Message) error
	Save(string, proto.Message) error
	Delete(string) error
}

func NewEphemeralProtoStore added in v0.0.18

func NewEphemeralProtoStore() ProtoStore

func NewFSProtoStore added in v0.0.18

func NewFSProtoStore(dir string) (ProtoStore, error)

NewFSProtoStore returns a filesystem based store starting at dir.

type Store

type Store interface {
	Load(string) ([]byte, error)
	Save(string, []byte) error
	Delete(string) error
}

func NewFSStore

func NewFSStore(dir string) (Store, error)

NewFSStore returns a filesystem based store starting at dir.

Jump to