Documentation
¶
Overview ¶
Package store provides an interface as well as implementations for storing proto messages to various surfaces.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ProtoStore ¶ added in v0.0.18
type ProtoStore interface {
Load(string, proto.Message) error
Save(string, proto.Message) error
Delete(string) error
}
func NewEphemeralProtoStore ¶ added in v0.0.18
func NewEphemeralProtoStore() ProtoStore
func NewFSProtoStore ¶ added in v0.0.18
func NewFSProtoStore(dir string) (ProtoStore, error)
NewFSProtoStore returns a filesystem based store starting at dir.
Click to show internal directories.
Click to hide internal directories.